 function lambda_min = e_matrix(A,n)
 % Function E_MATRIX is used for finding the minimum eigenvalue
 % of the interval matrix family [A].
 %
 % LAMBDA_MIN = E_MATRIX(A,n) attempts to find the minimum eigenvalue 
 % of the interval matrix family [A]. Function accepts input A as an
 % interval matrix and input n as a real number.
 %
 % Two choices of the matrix E have been used to illustrative this alpha
 % calculation method:
 %
 % if n = 1 then E = 0 where E is a square matrix of n-dimensional.
 % if n = 2 then E = diag(deltaA) where delta A is a radius matrix family
 % [A].
 %
 % Created by Andrea Szakalova on 9.3.2011

A_dol = A.inf;
deltaA = A.rad;
deltaA_modif = deltaA-diag(diag(deltaA));
A_midpoint = A.mid;
A_midpoint_modif = A_midpoint-diag(diag(A_midpoint))+diag(diag(A_dol));

if n==1
     E=0;
 elseif n==2
      E=diag(diag(deltaA));
end
lambda_min = min(eig(A_midpoint_modif+E))-max(abs(eig(deltaA_modif-abs(E))));
 end