function lambda_min = kharitonov(A)
% The Kharitonov method is used to determine an interval polynomial family.
% Derive the determinat of H(x)-lambda*I and set it to zero.
% LAMBDA_MIN = KHARITONOV(A) gives a lower bound on the minimum eigenvalue
% of A(x).
% K1, K2, K3 and K4 are four real Kharitonov polynomials.
% Lambda is the minimum roots of the four polynomials.
% Created by Andrea Szaklov on 28.4.2011.

fid=fopen('matica.m','w+');
[n,n] = size(A);
for i=1:n;
    for j=1:n;
        fprintf(fid, 'syms a%d%d\n',i,j);
    end
end

fprintf(fid, 'H=[');
for i=1:n;
    for j=1:n;
        fprintf(fid, 'a%d%d ',i,j);
    end
    fprintf(fid,'\n');
end
fprintf(fid,'];');
fclose(fid);

matica
syms lambda
I = eye(n);
K = collect(det(H-lambda*I));
if rem(n,2)
    K = K*(-1);
end

a11 = A(1,1);
a12 = A(1,2);
a21 = A(2,1);
a22 = A(2,2);
a1 = -(a11 + a22);
a0 = (a11*a22 - a12*a21);
a1L = a1.inf;
a1U = a1.sup;
a0L = a0.inf;
a0U = a0.sup;

% Definovanie Kharitonovch polynmov: 
K1 = a0L + a1L*lambda + lambda^2;
K2 = a0U + a1U*lambda + lambda^2;
K3 = a0U + a1L*lambda + lambda^2;
K4 = a0L + a1U*lambda + lambda^2;

% Vpoet koreov tyroch Kharitonovch polynmov:
lambda1 = roots([1 a1L a0L]);
lambda2 = roots([1 a1U a0U]);
lambda3 = roots([1 a1L a0U]);
lambda4 = roots([1 a1U a0L]);

lambda = min(lambda1);
lambda = min(min(lambda2),lambda);
lambda = min(min(lambda3),lambda);
lambda_min = min(min(lambda4),lambda);
end


    


