 function lambda_min = lbh(A)
 % The function LBH is used for finding the minimum eigenvalue of the 
 % symmetric interval matrix family [A] using lower bounding Hessian
 % method.
 %
 % LAMBDA_MIN = LBH(A)finds the minimum of the lambda. Function accepts 
 % input A as an interval matrix 
 %
 % The lower bounding Hessian is a guaranteed lower bound on the minimum
 % eigenvalue of the interval matrix family.
 %
 % Created by Andrea Szakalova on  16.3.2011
 
A_dol = A.inf;
A_midpoint = A.mid;
LA_dol = diag(diag(A_dol));
AR_dol = -A.rad;
AR_nula = AR_dol-diag(diag(AR_dol));
LRS = diag(sum(AR_nula,2));
L1 = LA_dol+LRS;
L2 = A_midpoint-diag(diag(A_midpoint));
L = L1+L2;
lambda_min = min(eig(L));
 end