function alfa_i = mmsd(A,xL,xU)
% Minimization of maximum separation distance
% This method aims to drive a nonuniform diagonal shift matrix delta, which
% is optimal with respect of d_max where d_max is maximumm separation
% distance.
%
% ALFA_I = MMSD(A,xL,xU) will find a different alfa value. Function 
% accepts input A, xL a nd xU, where [A] is a symmetric interval matrix,xL
% is a lower bound and xU is an upper bound of objective function.
%
% Created by Andrea Szakalova on 18.11.2011

% xL = [-1;-1]; 
% xU = [2;1];

% the lower bounding Hessian L:
A_dol = A.inf;
A_midpoint = A.mid;
LA_dol = diag(diag(A_dol));
AR_dol = -A.rad;
AR_nula = AR_dol - diag(diag(AR_dol));
LRS = diag(sum(AR_nula,2));
L1 = LA_dol + LRS;
L2 = A_midpoint - diag(diag(A_midpoint));
L = L1+L2;

n = length(A);
alfa = ones(n,1);
alfa_min = -Inf*ones(n,1);
alfa_max = Inf*ones(n,1);
[x,fval,exitflag] = fmincon(@objfun,alfa,[],[],[],[],alfa_min,alfa_max,...
                            @confun,optimset('display','off'),L,xL,xU);

function f = objfun(alfa,L,xL,xU)
 % delta = diag(alfa);
 f = 1/4.*(xU-xL)'*diag(alfa)*(xU-xL);
end
 
 function [c,ceq] = confun(alfa,L,xL,xU)
 c = -eig(L+2*diag(alfa));
 ceq = [];
 end
alfa_i = x;
end

